@@ -31,8 +31,9 @@ Assamese_LO_Latest_full
    <fr_BE>Assamese Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue assamaise pour LibreOffice</fr>
    <gl_ES>Asamés Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Assamese Language Meta-Package for LibreOffice</gu>
    <he_IL>Assamese Language Meta-Package for LibreOffice</he_IL>
-   <hi>Assamese Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु असमी भाषा मेटा-पैकेज</hi>
    <hr>Assamese Language Meta-Package for LibreOffice</hr>
    <hu>Assamese Language Meta-Package for LibreOffice</hu>
    <id>Assamese Language Meta-Package for LibreOffice</id>
