@@ -21,23 +21,24 @@ Galician_Thunderbird
    <de>Galegische Lokalisation von “Thunderbird”</de>
    <el>Γαλικία για Thunderbird</el>
    <en>Galician localisation of Thunderbird</en>
-   <es_ES>Galician localisation of Thunderbird</es_ES>
+   <es_ES>Localización Gallego de Thunderbird</es_ES>
    <es>Localización Gallego de Thunderbird</es>
    <et>Galician localisation of Thunderbird</et>
    <eu>Galician localisation of Thunderbird</eu>
    <fa>Galician localisation of Thunderbird</fa>
    <fil_PH>Galician localisation of Thunderbird</fil_PH>
    <fi>Galician localisation of Thunderbird</fi>
-   <fr_BE>Localisation en galicien de Thunderbird</fr_BE>
+   <fr_BE>Galician localisation of Thunderbird</fr_BE>
    <fr>Localisation en galicien de Thunderbird</fr>
    <gl_ES>Galician localisation of Thunderbird</gl_ES>
+   <gu>Galician localisation of Thunderbird</gu>
    <he_IL>Galician localisation of Thunderbird</he_IL>
    <hi>Galician localisation of Thunderbird</hi>
    <hr>Galician localisation of Thunderbird</hr>
    <hu>Galician localisation of Thunderbird</hu>
    <id>Galician localisation of Thunderbird</id>
    <is>Galician localisation of Thunderbird</is>
-   <it>Galician localisation of Thunderbird</it>
+   <it>Localizzazione galiziana di Thunderbird</it>
    <ja>ガリシア語版 Thunderbird</ja>
    <kk>Galician localisation of Thunderbird</kk>
    <ko>Galician localisation of Thunderbird</ko>
@@ -50,7 +51,7 @@ Galician_Thunderbird
    <nl>Galician localisation of Thunderbird</nl>
    <pl>Galician localisation of Thunderbird</pl>
    <pt_BR>Galego Localização para o Thunderbird</pt_BR>
-   <pt>Galician localisation of Thunderbird</pt>
+   <pt>Tradução em Galego para Thunderbird</pt>
    <ro>Galician localisation of Thunderbird</ro>
    <ru>Galician localisation of Thunderbird</ru>
    <sk>Galician localisation of Thunderbird</sk>
@@ -59,7 +60,7 @@ Galician_Thunderbird
    <sr>Galician localisation of Thunderbird</sr>
    <sv>Galicisk lokalisering av Thunderbird</sv>
    <th>Galician localisation of Thunderbird</th>
-   <tr>Galician localisation of Thunderbird</tr>
+   <tr>Thunderbird Galiçyaca yerelleştirmesi</tr>
    <uk>Galician localisation of Thunderbird</uk>
    <vi>Galician localisation of Thunderbird</vi>
    <zh_CN>Galician localisation of Thunderbird</zh_CN>
