@@ -28,9 +28,10 @@ Serbian_LO_main
    <fa>Serbian Language Meta-Package for LibreOffice</fa>
    <fil_PH>Serbian Language Meta-Package for LibreOffice</fil_PH>
    <fi>Serbialainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet langue serbe pour LibreOffice</fr_BE>
+   <fr_BE>Serbian Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet langue serbe pour LibreOffice</fr>
    <gl_ES>Serbio Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Serbian Language Meta-Package for LibreOffice</gu>
    <he_IL>Serbian Language Meta-Package for LibreOffice</he_IL>
    <hi>Serbian Language Meta-Package for LibreOffice</hi>
    <hr>Serbian Language Meta-Package for LibreOffice</hr>
